@@ -23,11 +23,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QItemSelectionModel>
 #include <QTimer>
 #include <QUndoGroup>
-#include <QUrl>
 
 // KDE
 #include <KDirLister>
-#include <KFileItem>
 #include <KProtocolManager>
 
 // Local
@@ -331,7 +329,7 @@ void ContextManager::slotRowsInserted()
     // thumbnail bar is visible, the image will not be selected in the thumbnail
     // bar.
     if (d->mUrlToSelect.isValid()) {
-        QMetaObject::invokeMethod(this, "selectUrlToSelect", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &ContextManager::selectUrlToSelect, Qt::QueuedConnection);
     }
 }
 
