@@ -273,7 +273,7 @@ void RasterImageView::loadFromDocument()
 void RasterImageView::slotDocumentMetaInfoLoaded()
 {
     if (document()->size().isValid()) {
-        QMetaObject::invokeMethod(this, "finishSetDocument", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &RasterImageView::finishSetDocument, Qt::QueuedConnection);
     } else {
         // Could not retrieve image size from meta info, we need to load the
         // full image now.
