@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gvdebug.h>
 
 // Qt
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QUrl>
 
 // KDE
@@ -79,7 +79,7 @@ void BalooSemanticInfoBackend::storeSemanticInfo(const QUrl &url, const Semantic
     KFileMetaData::UserMetaData md(url.toLocalFile());
     md.setRating(semanticInfo.mRating);
     md.setUserComment(semanticInfo.mDescription);
-    md.setTags(semanticInfo.mTags.toList());
+    md.setTags(semanticInfo.mTags.values());
 }
 
 void BalooSemanticInfoBackend::retrieveSemanticInfo(const QUrl &url)
